==> haskell-unexceptionalio-0.3.0-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-unexceptionalio.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: unexceptionalio
version: 0.3.0
id: unexceptionalio-0.3.0-3nDcFbDMfKl1BSaDMqCv5B
key: unexceptionalio-0.3.0-3nDcFbDMfKl1BSaDMqCv5B
license: OtherLicense
copyright: © 2013-2014 Stephen Paul Weber
maintainer: Stephen Paul Weber <singpolyma@singpolyma.net>
stability: experimental
homepage: https://github.com/singpolyma/unexceptionalio
synopsis: IO without any non-error, synchronous exceptions
description:
    When you'\''ve caught all the exceptions that can be handled safely,
    this is what you'\''re left with.
    .
    It is intended that you use qualified imports with this library.
    .
    > import UnexceptionalIO (UIO)
    > import qualified UnexceptionalIO as UIO
category: Control
author: Stephen Paul Weber <singpolyma@singpolyma.net>
exposed: True
exposed-modules:
    UnexceptionalIO
abi: 1130d31d807bf6e865252407e635939f
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/unexceptionalio-0.3.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/unexceptionalio-0.3.0
data-dir: /usr/share/i386-linux-ghc-8.0.1/unexceptionalio-0.3.0
hs-libraries: HSunexceptionalio-0.3.0-3nDcFbDMfKl1BSaDMqCv5B
depends:
    base-4.9.0.0
haddock-interfaces: /usr/share/doc/haskell-unexceptionalio/html/unexceptionalio.haddock
haddock-html: /usr/share/doc/haskell-unexceptionalio/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unexceptionalio-0.3.0-4-i686.pkg.tar.xz: usr/share/haskell/register/haskell-unexceptionalio.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: unexceptionalio
version: 0.3.0
id: unexceptionalio-0.3.0-2Qrq3kcp0PEBvJTmGgkrK4
key: unexceptionalio-0.3.0-2Qrq3kcp0PEBvJTmGgkrK4
license: OtherLicense
copyright: © 2013-2014 Stephen Paul Weber
maintainer: Stephen Paul Weber <singpolyma@singpolyma.net>
stability: experimental
homepage: https://github.com/singpolyma/unexceptionalio
synopsis: IO without any non-error, synchronous exceptions
description:
    When you'\''ve caught all the exceptions that can be handled safely,
    this is what you'\''re left with.
    .
    It is intended that you use qualified imports with this library.
    .
    > import UnexceptionalIO (UIO)
    > import qualified UnexceptionalIO as UIO
category: Control
author: Stephen Paul Weber <singpolyma@singpolyma.net>
exposed: True
indefinite: False
exposed-modules:
    UnexceptionalIO
abi: 3d2f66864f260fa643bed05649f7fe57
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/unexceptionalio-0.3.0
library-dirs: /usr/lib/ghc-8.2.1/site-local/unexceptionalio-0.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/unexceptionalio-0.3.0
hs-libraries: HSunexceptionalio-0.3.0-2Qrq3kcp0PEBvJTmGgkrK4
depends:
    base-4.10.0.0
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
haddock-interfaces: /usr/share/doc/haskell-unexceptionalio/html/unexceptionalio.haddock
haddock-html: /usr/share/doc/haskell-unexceptionalio/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
